@@ -155,7 +155,7 @@ class PostProcessingJob:
         return self.all_metadata[-1]
     
     def get_id(self):
-        return utils.search_regex_id(self.opened_path)
+        return utils.search_regex_id(self.opened_path, group=True)
     
     def set_regression_points(self, other):
         logging.debug(f"Setting new regression points: {other}")
@@ -575,8 +575,11 @@ def plot_powerlaw(
     result = scipy.stats.linregress(xs_to_fit, ys_to_fit)
     intercept = result.intercept
     slope = result.slope
-    intercept_stderr = result.intercept_stderr
-    logging.info(f"Uncertainty of intercept (no exponential propagation): {intercept_stderr}")
+    try:
+        intercept_stderr = result.intercept_stderr
+        logging.info(f"Uncertainty of intercept (no exponential propagation): {intercept_stderr}")
+    except AttributeError:
+        logging.info("Error in finding stderr of intercept")
 
     if mode == 'log':
         values = [slope, np.exp(intercept)]
@@ -951,7 +954,7 @@ def plot_trajectory_lengths(
     message += f"Average length: {np.average(counts)}\n"
     message += f"Min, max length: {np.min(counts)}, {np.max(counts)}\n"
     message += f"St. Dev. length: {np.std(counts)}\n"
-    message += f"Mode length: {scipy.stats.mode(counts, keepdims=False).mode} (count={scipy.stats.mode(counts, keepdims=False).count})"
+    message += f"Mode length: {scipy.stats.mode(counts).mode} (count={scipy.stats.mode(counts).count})"
     logging.info(message)
     table_var['Total count'] = len(unique)
     table_var['Average/frame'] = len(unique)/sum(num_frames_list)
@@ -959,8 +962,8 @@ def plot_trajectory_lengths(
     table_var["Min length"] = np.min(counts)
     table_var["Max length"] = np.max(counts)
     table_var["St. Dev. length"] = np.std(counts)
-    table_var["Mode length"] = scipy.stats.mode(counts, keepdims=False).mode
-    table_var["Mode count"] = scipy.stats.mode(counts, keepdims=False).count
+    table_var["Mode length"] = scipy.stats.mode(counts).mode
+    table_var["Mode count"] = scipy.stats.mode(counts).count
 
     if memory != 0:
         message = "Memory information"
